==> cargo-search2-0.2.1.crate: cargo-search2-0.2.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](https://semver.org), where the API is the command-line interface.

## [0.2.1] - 2021-10-10

- Fix version number in `Cargo.toml`.

## [0.2.0] - 2021-10-10

- Add a `-c`/`--cache-version` option to easily invalidate caches from the command line.
- Define stability guarantees.
- This version is a breaking change because hashes are now computed differently.

## [0.1.1] - 2021-10-03

- Republished 0.1.0 (it had accidentally been published earlier).

## [0.1.0] - 2021-10-03

- First (real) release.
- Add `plain` and `toml` message formats, and switch the default to `plain`.

## [0.0.5] - 2021-10-03

- Fix GitHub messasge format.

## [0.0.4] - 2021-10-03

- Need to push to `main` before pushing tags.

## [0.0.3] - 2021-10-03

- Fix version number in `Cargo.toml`.

## [0.0.2] - 2021-10-03

- Remove musl build -- git requires openssl which is harder to build on musl.

[0.0.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.2

## [0.0.1] - 2021-10-03

- Initial release.

[0.2.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.2.1
[0.2.0]: https://github.com/sunshowers/cargo-search2/releases/tag/0.2.0
[0.1.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.1.1
[0.1.0]: https://github.com/sunshowers/cargo-search2/releases/tag/0.1.0
[0.0.5]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.5
[0.0.4]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.4
[0.0.3]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.3
[0.0.2]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.2
[0.0.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.1

==> cargo-search2-0.2.2.crate: cargo-search2-0.2.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

This project adheres to [Semantic Versioning](https://semver.org), where the API is the command-line interface.

## [0.2.2] - 2021-10-11

- Use `BareIndex` rather than `Index` to speed up initial checkout times.

## [0.2.1] - 2021-10-10

- Fix version number in `Cargo.toml`.

## [0.2.0] - 2021-10-10

- Add a `-c`/`--cache-version` option to easily invalidate caches from the command line.
- Define stability guarantees.
- This version is a breaking change because hashes are now computed differently.

## [0.1.1] - 2021-10-03

- Republished 0.1.0 (it had accidentally been published earlier).

## [0.1.0] - 2021-10-03

- First (real) release.
- Add `plain` and `toml` message formats, and switch the default to `plain`.

## [0.0.5] - 2021-10-03

- Fix GitHub messasge format.

## [0.0.4] - 2021-10-03

- Need to push to `main` before pushing tags.

## [0.0.3] - 2021-10-03

- Fix version number in `Cargo.toml`.

## [0.0.2] - 2021-10-03

- Remove musl build -- git requires openssl which is harder to build on musl.

[0.0.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.2

## [0.0.1] - 2021-10-03

- Initial release.

[0.2.2]: https://github.com/sunshowers/cargo-search2/releases/tag/0.2.2
[0.2.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.2.1
[0.2.0]: https://github.com/sunshowers/cargo-search2/releases/tag/0.2.0
[0.1.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.1.1
[0.1.0]: https://github.com/sunshowers/cargo-search2/releases/tag/0.1.0
[0.0.5]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.5
[0.0.4]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.4
[0.0.3]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.3
[0.0.2]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.2
[0.0.1]: https://github.com/sunshowers/cargo-search2/releases/tag/0.0.1
